==> opennms-dao-mock-14.0.3-20190511.214144-6-sources.jar: org/opennms/netmgt/dao/mock/MockRequisitionedCategoryAssociationDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;

import org.opennms.netmgt.dao.api.RequisitionedCategoryAssociationDao;
import org.opennms.netmgt.model.RequisitionedCategoryAssociation;

public class MockRequisitionedCategoryAssociationDao extends AbstractMockDao<RequisitionedCategoryAssociation, Integer> implements RequisitionedCategoryAssociationDao {
    private AtomicInteger m_id = new AtomicInteger(0);

    @Override
    public void save(final RequisitionedCategoryAssociation cat) {
        super.save(cat);
        updateSubObjects(cat);
    }

    private void updateSubObjects(final RequisitionedCategoryAssociation cat) {
        getNodeDao().save(cat.getNode());
        getCategoryDao().save(cat.getCategory());
    }

    @Override
    public List<RequisitionedCategoryAssociation> findByNodeId(final Integer nodeId) {
        final List<RequisitionedCategoryAssociation> ret = new ArrayList<>();
        if (nodeId != null) {
            for (final RequisitionedCategoryAssociation assoc : findAll()) {
                if (assoc.getNode() != null && nodeId.equals(assoc.getNode().getId())) {
                    ret.add(assoc);
                }
            }
        }
        return ret;
    }

    @Override
    protected Integer getId(final RequisitionedCategoryAssociation entity) {
        return entity.getId();
    }

    @Override
    protected void generateId(final RequisitionedCategoryAssociation entity) {
        entity.setId(m_id.incrementAndGet());
    }

}

==> opennms-dao-mock-17.1.1-sources.jar: org/opennms/netmgt/dao/mock/MockRequisitionedCategoryAssociationDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;

import org.opennms.netmgt.dao.api.RequisitionedCategoryAssociationDao;
import org.opennms.netmgt.model.RequisitionedCategoryAssociation;

public class MockRequisitionedCategoryAssociationDao extends AbstractMockDao<RequisitionedCategoryAssociation, Integer> implements RequisitionedCategoryAssociationDao {
    private AtomicInteger m_id = new AtomicInteger(0);

    @Override
    public Integer save(final RequisitionedCategoryAssociation cat) {
        Integer retval = super.save(cat);
        updateSubObjects(cat);
        return retval;
    }

    private void updateSubObjects(final RequisitionedCategoryAssociation cat) {
        getNodeDao().save(cat.getNode());
        getCategoryDao().save(cat.getCategory());
    }

    @Override
    public List<RequisitionedCategoryAssociation> findByNodeId(final Integer nodeId) {
        final List<RequisitionedCategoryAssociation> ret = new ArrayList<>();
        if (nodeId != null) {
            for (final RequisitionedCategoryAssociation assoc : findAll()) {
                if (assoc.getNode() != null && nodeId.equals(assoc.getNode().getId())) {
                    ret.add(assoc);
                }
            }
        }
        return ret;
    }

    @Override
    protected Integer getId(final RequisitionedCategoryAssociation entity) {
        return entity.getId();
    }

    @Override
    protected void generateId(final RequisitionedCategoryAssociation entity) {
        entity.setId(m_id.incrementAndGet());
    }

}
